==> nextcloud-29.0.7.tar.bz2: nextcloud/apps/files_downloadlimit/l10n/ru.js <==
OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "Лимит загрузки файлов",
    "File link share download limit" : "Ограничение на скачивание файловой ссылки",
    "This app allows limiting the number of downloads for external link shares." : "Это приложение позволяет ограничить количество загрузок для обмена внешними ссылками.",
    "Limit downloads" : "Лимит загрузок",
    "Set download limit" : "Установите лимит загрузки",
    "Setting a new limit will reset the download count" : "Установка нового лимита приведет к сбросу количества загрузок",
    "The minimum limit is 1" : "Минимальный предел составляет 1",
    "Failed to set download limit" : "Не удалось установить лимит загрузки",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["{count} оставшаяся разрешённая загрузка","{count} оставшихся разрешённых загрузки","{count} оставшихся разрешённых загрузок","{count} оставшихся разрешённых загрузок"],
    "Download limit" : "Лимит скачивания",
    "Configure the default download limit for external shares." : "Настройка ограничения загрузки по умолчанию для внешних общих ресурсов.",
    "Set default download limit" : "Установить лимит загрузки по умолчанию",
    "You have reached the maximum amount of downloads allowed" : "Вы достигли максимально допустимого количества загрузок",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "У этого общего ресурса ограниченное количество загрузок. Вы уверены, что хотите запустить новую загрузку?",
    "Allow to limit the number of downloads for link shares" : "Разрешить ограничивать количество скачиваний для обмена ссылками",
    "This share was limited to {limit} downloads. There is still {countLeft} left allowed." : "Этот ресурс был ограничен {limit} загрузками. Осталось {countLeft} загрузок."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-31.0.10.tar.bz2: nextcloud/apps/files_downloadlimit/l10n/ru.js <==
OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "Лимит загрузки файлов",
    "File link share download limit" : "Ограничение на скачивание файловой ссылки",
    "This app allows limiting the number of downloads for external link shares." : "Это приложение позволяет ограничить количество загрузок для обмена внешними ссылками.",
    "The minimum limit is 1" : "Минимальный предел составляет 1",
    "Failed to set download limit" : "Не удалось установить лимит загрузки",
    "Failed to remove download limit" : "Не удалось снять ограничение на загрузку",
    "Limit downloads" : "Лимит загрузок",
    "Set download limit" : "Установите лимит загрузки",
    "Setting a new limit will reset the download count" : "Установка нового лимита приведет к сбросу количества загрузок",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["{count} оставшаяся разрешённая загрузка","{count} оставшихся разрешённых загрузки","{count} оставшихся разрешённых загрузок","{count} оставшихся разрешённых загрузок"],
    "Download limit" : "Лимит скачивания",
    "Configure the default download limit for external shares." : "Настройка ограничения загрузки по умолчанию для внешних общих ресурсов.",
    "Set default download limit" : "Установить лимит загрузки по умолчанию",
    "You have reached the maximum amount of downloads allowed" : "Вы достигли максимально допустимого количества загрузок",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "У этого общего ресурса ограниченное количество загрузок. Вы уверены, что хотите запустить новую загрузку?",
    "Failed to set default download limit" : "Не удалось установить лимит загрузок по умолчанию"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
